pub fn parse_path(d: &str) -> Result<Vec<Instruction>, PathParseError>Expand description
Parses an SVG path d string into a list of Instructions.
pub fn parse_path(d: &str) -> Result<Vec<Instruction>, PathParseError>Parses an SVG path d string into a list of Instructions.